@@ -124,7 +124,11 @@ std::shared_ptr<QPDF> open_pdf(py::object filename_or_stream,
         success = true;
     }
 
-    // At this point, either we succeeded or threw an exception
+    if (!success) {
+        // LCOV_EXCL_LINE
+        throw std::logic_error(
+            "open_pdf: should have succeeded or thrown a Python exception");
+    }
 
     if (inherit_page_attributes) {
         // This could be expensive for a large file, plausibly (not tested),
@@ -525,7 +529,7 @@ void init_qpdf(py::module_ &m)
             R"~~~(
             Provides access to the PDF trailer object.
 
-            See section 7.5.5 of the PDF reference manual. Generally speaking,
+            See |pdfrm| section 7.5.5. Generally speaking,
             the trailer should not be modified with pikepdf, and modifying it
             may not work. Some of the values in the trailer are automatically
             changed when a file is saved.
