@@ -5,6 +5,7 @@ from pathlib import Path
 from xml.etree import ElementTree as ET
 
 import pytest
+from conftest import skip_if_pypy
 from hypothesis import assume, example, given, settings
 from hypothesis import strategies as st
 from hypothesis.extra.dateutil import timezones
@@ -556,6 +557,7 @@ def test_extension_level(trivial, outpdf):
         trivial.save(outpdf, force_version=('1.7', 'invalid extension level'))
 
 
+@settings(deadline=500.0)
 @given(
     st.dictionaries(
         keys=st.sampled_from(
@@ -578,6 +580,7 @@ def test_extension_level(trivial, outpdf):
         ),
     )
 )
+@skip_if_pypy
 def test_random_docinfo(docinfo):
     p = pikepdf.new()
     with p.open_metadata() as m:
@@ -606,6 +609,7 @@ def test_random_docinfo(docinfo):
         values=st.none() | st.characters(blacklist_categories=('Cs',)),
     )
 )
+@skip_if_pypy
 def test_random_valid_docinfo(docinfo):
     p = pikepdf.new()
     with p.open_metadata() as m:
@@ -729,3 +733,27 @@ def test_exception_undoes_edits(graph):
             raise
         m = graph.open_metadata()
         assert m['dc:format'] != 'application/pdf-demo'
+
+
+def test_xxe(trivial, outdir):
+    secret = outdir / 'secret.txt'
+    secret.write_text("This is a secret")
+    trivial.Root.Metadata = Stream(
+        trivial,
+        b"""\
+<?xpacket begin='\xef\xbb\xbf' id='W5M0MpCehiHzreSzNTczkc9d'?>
+<!DOCTYPE rdf:RDF [<!ENTITY xxe SYSTEM "file://%s">]>
+<x:xmpmeta xmlns:x='adobe:ns:meta/' x:xmptk='Image'>
+<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
+<note>
+<to>&xxe;</to>
+<from>xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx</from>
+</note>
+</rdf:RDF>
+</x:xmpmeta>
+<?xpacket end='w'?>
+    """
+        % os.fsencode(secret),
+    )
+    with trivial.open_metadata() as m:
+        assert 'This is a secret' not in str(m)
