@@ -66,7 +66,8 @@ def test_unicode_involution(s):
 
 @given(characters(whitelist_categories=('Cs',)))
 def test_unicode_fails(s):
-    with pytest.raises(RuntimeError):
+    # pybind11 < 2.7 raises RuntimeError, == 2.7 raises UnicodeEncodeError
+    with pytest.raises((RuntimeError, UnicodeEncodeError)):
         encode(s)
 
 
